@@ -365,12 +365,12 @@ int FileRenamerWidget::addRowCategory(TagType category)
     QVBoxLayout *optionLayout = new QVBoxLayout;
     frameLayout->addLayout(optionLayout);
 
-    row.enableButton = new KPushButton(i18n("Remove"), frame);
+    row.enableButton = new KPushButton(i18nc("remove music genre from file renamer", "Remove"), frame);
     optionLayout->addWidget(row.enableButton);
     toggleMapper->connect(row.enableButton, SIGNAL(clicked()), SLOT(map()));
     toggleMapper->setMapping(row.enableButton, id);
 
-    row.optionsButton = new KPushButton(i18n("Options"), frame);
+    row.optionsButton = new KPushButton(i18nc("file renamer genre options", "Options"), frame);
     optionLayout->addWidget(row.optionsButton);
     mapper->connect(row.optionsButton, SIGNAL(clicked()), SLOT(map()));
     mapper->setMapping(row.optionsButton, id);
@@ -485,7 +485,7 @@ void FileRenamerWidget::createTagRows()
     QList<int> categoryOrder = config.readEntry("CategoryOrder", QList<int>());
 
     if(categoryOrder.isEmpty())
-        categoryOrder << Artist << Album << Artist << Title << Track;
+        categoryOrder << Artist << Album << Title << Track;
 
     // Setup arrays.
     m_rows.reserve(categoryOrder.count());
