@@ -53,6 +53,8 @@
 #include "k3bexporter.h"
 #include "tracksequencemanager.h"
 #include "tagtransactionmanager.h"
+#include "playermanager.h"
+#include "dbuscollectionproxy.h"
 
 using namespace ActionCollection;
 
@@ -60,7 +62,7 @@ using namespace ActionCollection;
 // PlaylistBox public methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistBox::PlaylistBox(QWidget *parent, Q3WidgetStack *playlistStack) :
+PlaylistBox::PlaylistBox(QWidget *parent, QStackedWidget *playlistStack) :
     K3ListView(parent),
     PlaylistCollection(playlistStack),
     m_viewModeIndex(0),
@@ -134,7 +136,7 @@ PlaylistBox::PlaylistBox(QWidget *parent, Q3WidgetStack *playlistStack) :
             this, SLOT(slotPlaylistChanged()));
 
     connect(this, SIGNAL(doubleClicked(Q3ListViewItem *)),
-            this, SLOT(slotDoubleClicked()));
+            this, SLOT(slotDoubleClicked(Q3ListViewItem *)));
 
     connect(this, SIGNAL(contextMenuRequested(Q3ListViewItem *, const QPoint &, int)),
             this, SLOT(slotShowContextMenu(Q3ListViewItem *, const QPoint &, int)));
@@ -154,14 +156,13 @@ PlaylistBox::PlaylistBox(QWidget *parent, Q3WidgetStack *playlistStack) :
     QTimer::singleShot(0, object(), SLOT(slotScanFolders()));
     enableDirWatch(true);
 
-    // Auto-save playlists after they change.
-    m_savePlaylistTimer = new QTimer(this);
-    m_savePlaylistTimer->setInterval(3000); // 3 seconds with no change? -> commit
-    m_savePlaylistTimer->setSingleShot(true);
-    connect(m_savePlaylistTimer, SIGNAL(timeout()), SLOT(slotSavePlaylists()));
+    m_savePlaylistTimer = 0;
 
     m_showTimer = new QTimer(this);
     connect(m_showTimer, SIGNAL(timeout()), SLOT(slotShowDropTarget()));
+
+    // hook up to the D-Bus
+    (void) new DBusCollectionProxy(this, this);
 }
 
 PlaylistBox::~PlaylistBox()
@@ -239,7 +240,8 @@ void PlaylistBox::slotUnfreezePlaylists()
 
 void PlaylistBox::slotPlaylistDataChanged()
 {
-    m_savePlaylistTimer->start(); // Restarts the timer if it's already running.
+    if(m_savePlaylistTimer)
+        m_savePlaylistTimer->start(); // Restarts the timer if it's already running.
 }
 
 void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName)
@@ -263,8 +265,10 @@ void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName, Ite
 void PlaylistBox::removePlaylist(Playlist *playlist)
 {
     // Could be false if setup() wasn't run yet.
-    if(m_playlistDict.contains(playlist))
+    if(m_playlistDict.contains(playlist)) {
         removeNameFromDict(m_playlistDict[playlist]->text(0));
+        delete m_playlistDict[playlist]; // Delete the Item*
+    }
 
     removeFileFromDict(playlist->fileName());
     m_playlistDict.remove(playlist);
@@ -659,10 +663,23 @@ void PlaylistBox::slotPlaylistChanged()
         createDynamicPlaylist(playlists);
 }
 
-void PlaylistBox::slotDoubleClicked()
+void PlaylistBox::slotDoubleClicked(Q3ListViewItem *item)
 {
-    action("stop")->trigger();
-    action("play")->trigger();
+    TrackSequenceManager *manager = TrackSequenceManager::instance();
+    Item *playlistItem = static_cast<Item *>(item);
+
+    if(item)
+        manager->setCurrentPlaylist(playlistItem->playlist());
+
+    manager->setCurrent(0); // Reset playback
+    PlaylistItem *next = manager->nextItem(); // Allow manager to choose
+
+    if(next) {
+        PlayerManager::instance()->play(next->file());
+        playlistItem->playlist()->setPlaying(next);
+    }
+    else
+        action("stop")->trigger();
 }
 
 void PlaylistBox::slotShowContextMenu(Q3ListViewItem *, const QPoint &point, int)
@@ -704,6 +721,13 @@ void PlaylistBox::setupUpcomingPlaylist()
 void PlaylistBox::slotLoadCachedPlaylists()
 {
     Cache::loadPlaylists(this);
+
+    // Auto-save playlists after they change.
+    m_savePlaylistTimer = new QTimer(this);
+    m_savePlaylistTimer->setInterval(3000); // 3 seconds with no change? -> commit
+    m_savePlaylistTimer->setSingleShot(true);
+    connect(m_savePlaylistTimer, SIGNAL(timeout()), SLOT(slotSavePlaylists()));
+
     emit startupComplete();
 }
 ////////////////////////////////////////////////////////////////////////////////
@@ -810,7 +834,6 @@ void PlaylistBox::Item::init()
     if(m_playlist) {
         connect(m_playlist, SIGNAL(signalNameChanged(const QString &)),
                 this, SLOT(slotSetName(const QString &)));
-        connect(m_playlist, SIGNAL(destroyed()), this, SLOT(deleteLater()));
         connect(m_playlist, SIGNAL(signalEnableDirWatch(bool)),
                 list->object(), SLOT(slotEnableDirWatch(bool)));
     }
