@@ -18,39 +18,37 @@
 
 #include "playlistcollection.h"
 
-#include <klistview.h>
+#include <k3listview.h>
 
-#include <qptrdict.h>
+#include <QHash>
 
 class Playlist;
 class PlaylistItem;
 class ViewMode;
-class PlaylistSearch;
-class SearchPlaylist;
 
-class KPopupMenu;
-class KSelectAction;
+class KMenu;
 
-typedef QValueList<Playlist *> PlaylistList;
+template<class T>
+class QList;
 
-/** 
- * This is the play list selection box that is by default on the right side of
- * JuK's main widget (PlaylistSplitter). 
+typedef QList<Playlist *> PlaylistList;
+
+/**
+ * This is the play list selection box that is by default on the left side of
+ * JuK's main widget (PlaylistSplitter).
  */
 
-class PlaylistBox : public KListView, public PlaylistCollection
+class PlaylistBox : public K3ListView, public PlaylistCollection
 {
     Q_OBJECT
 
-public: 
+public:
     class Item;
-    typedef QValueList<Item *> ItemList;
+    typedef QList<Item *> ItemList;
 
     friend class Item;
 
-    PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
-		const char *name = 0);
-
+    PlaylistBox(QWidget *parent, QStackedWidget *playlistStack);
     virtual ~PlaylistBox();
 
     virtual void raise(Playlist *playlist);
@@ -73,6 +71,7 @@ public slots:
 
     void slotFreezePlaylists();
     void slotUnfreezePlaylists();
+    void slotPlaylistDataChanged();
 
 protected:
     virtual void setupPlaylist(Playlist *playlist, const QString &iconName);
@@ -80,12 +79,13 @@ protected:
 
 signals:
     void signalPlaylistDestroyed(Playlist *);
+    void startupComplete(); ///< Emitted after playlists are loaded.
 
 private:
     void readConfig();
     void saveConfig();
 
-    virtual void decode(QMimeSource *s, Item *item);
+    virtual void decode(const QMimeData *s, Item *item);
     virtual void contentsDropEvent(QDropEvent *e);
     virtual void contentsDragMoveEvent(QDragMoveEvent *e);
     virtual void contentsDragLeaveEvent(QDragLeaveEvent *e);
@@ -94,8 +94,10 @@ private:
     virtual void keyPressEvent(QKeyEvent *e);
     virtual void keyReleaseEvent(QKeyEvent *e);
 
-    QValueList<Item *> selectedItems() const;
-    void setSingleItem(QListViewItem *item);
+    // selectedItems already used for something different
+
+    ItemList selectedBoxItems() const;
+    void setSingleItem(Q3ListViewItem *item);
 
     void setupItem(Item *item);
     void setupUpcomingPlaylist();
@@ -103,13 +105,13 @@ private:
     ViewMode *viewMode() const { return m_viewModes[m_viewModeIndex]; }
 
 private slots:
-    /** 
+    /**
      * Catches QListBox::currentChanged(QListBoxItem *), does a cast and then re-emits
-     * the signal as currentChanged(Item *). 
+     * the signal as currentChanged(Item *).
      */
     void slotPlaylistChanged();
-    void slotDoubleClicked();
-    void slotShowContextMenu(QListViewItem *, const QPoint &point, int);
+    void slotDoubleClicked(Q3ListViewItem *);
+    void slotShowContextMenu(Q3ListViewItem *, const QPoint &point, int);
     void slotSetViewMode(int index);
     void slotSavePlaylists();
     void slotShowDropTarget();
@@ -119,21 +121,23 @@ private slots:
     void slotAddItem(const QString &tag, unsigned column);
     void slotRemoveItem(const QString &tag, unsigned column);
 
+    // Used to load the playlists after GUI setup.
+    void slotLoadCachedPlaylists();
+
 private:
-    KPopupMenu *m_contextMenu;
-    QPtrDict<Item> m_playlistDict;
+    KMenu *m_contextMenu;
+    QHash<Playlist *, Item*> m_playlistDict;
     int m_viewModeIndex;
-    QValueList<ViewMode *> m_viewModes;
+    QList<ViewMode *> m_viewModes;
     KAction *m_k3bAction;
     bool m_hasSelection;
     bool m_doingMultiSelect;
     Item *m_dropItem;
     QTimer *m_showTimer;
+    QTimer *m_savePlaylistTimer;
 };
 
-
-
-class PlaylistBox::Item : public QObject, public KListViewItem
+class PlaylistBox::Item : public QObject, public K3ListViewItem, public PlaylistObserver
 {
     friend class PlaylistBox;
     friend class ViewMode;
@@ -148,29 +152,38 @@ class PlaylistBox::Item : public QObject, public KListViewItem
 
 public:
     virtual ~Item();
-    
+
 protected:
     Item(PlaylistBox *listBox, const QString &icon, const QString &text, Playlist *l = 0);
     Item(Item *parent, const QString &icon, const QString &text, Playlist *l = 0);
 
     Playlist *playlist() const { return m_playlist; }
-    PlaylistBox *listView() const { return static_cast<PlaylistBox *>(KListViewItem::listView()); }
+    PlaylistBox *listView() const { return static_cast<PlaylistBox *>(K3ListViewItem::listView()); }
     QString iconName() const { return m_iconName; }
     QString text() const { return m_text; }
     void setSortedFirst(bool first = true) { m_sortedFirst = first; }
 
-    virtual int compare(QListViewItem *i, int col, bool) const;
+    virtual int compare(Q3ListViewItem *i, int col, bool) const;
     virtual void paintCell(QPainter *p, const QColorGroup &colorGroup, int column, int width, int align);
     virtual void paintFocus(QPainter *, const QColorGroup &, const QRect &) {}
     virtual void setText(int column, const QString &text);
 
-    virtual QString text(int column) const { return KListViewItem::text(column); }
+    virtual QString text(int column) const { return K3ListViewItem::text(column); }
 
     virtual void setup();
 
     static Item *collectionItem() { return m_collectionItem; }
     static void setCollectionItem(Item *item) { m_collectionItem = item; }
 
+    //
+    // Reimplemented from PlaylistObserver
+    //
+
+    virtual void updateCurrent();
+
+    // Used to post a timer in PlaylistBox to save playlists.
+    virtual void updateData();
+
 
 protected slots:
     void slotSetName(const QString &name);
@@ -187,3 +200,5 @@ private:
 };
 
 #endif
+
+// vim: set et sw=4 tw=0 sta:
