@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2000 Rik Hemsley (rikkus) <rik@kde.org>
- * Copyright (C) 2000, 2001, 2002 Michael Matz <matz@kde.org>
+ * Copyright (C) 2000-2002 Michael Matz <matz@kde.org>
  * Copyright (C) 2001 Carsten Duvenhorst <duvenhorst@m2.uni-hannover.de>
  * Copyright (C) 2001 Adrian Schroeter <adrian@suse.de>
  * Copyright (C) 2003 Richard Lärkäng <richard@goteborg.utfors.se>
  * Copyright (C) 2003 Scott Wheeler <wheeler@kde.org>
- * Copyright (C) 2004, 2005 Benjamin Meyer <ben at meyerhome dot net>
+ * Copyright (C) 2004-2005 Benjamin Meyer <ben at meyerhome dot net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef AUDIO_CD_H
@@ -36,25 +36,25 @@ namespace AudioCD {
 /**
  * The core class of the audiocd:// ioslave.
  * It has the iosalve login and the ripping logic. The actual encoding
- * is done by encoders that are seperate objects.
+ * is done by encoders that are separate objects.
  */
 class AudioCDProtocol : public KIO::SlaveBase
 {
 	public:
 
-	AudioCDProtocol(const QCString & protocol, const QCString & pool, const QCString & app);
+	AudioCDProtocol(const QByteArray & protocol, const QByteArray & pool, const QByteArray & app);
 	virtual ~AudioCDProtocol();
 
-	virtual void get(const KURL &);
-	virtual void stat(const KURL &);
-	virtual void listDir(const KURL &);
+	virtual void get(const KUrl &);
+	virtual void stat(const KUrl &);
+	virtual void listDir(const KUrl &);
 
 	protected:
 	AudioCDEncoder *encoderFromExtension(const QString& extension);
 	AudioCDEncoder *determineEncoder(const QString & filename);
 
 	struct cdrom_drive *findDrive(bool &noPermission);
-	void parseURLArgs(const KURL &);
+	void parseURLArgs(const KUrl &);
 
 	void loadSettings();
 
@@ -86,7 +86,7 @@ class AudioCDProtocol : public KIO::SlaveBase
 		unsigned long size
 	);
 
-	struct cdrom_drive *initRequest(const KURL &);
+	struct cdrom_drive *initRequest(const KUrl &);
 	uint discid(struct cdrom_drive *);
 
 	/**
@@ -111,7 +111,7 @@ private:
 
 	void generateTemplateTitles();
 
-	QPtrList<AudioCDEncoder> encoders;
+	QList<AudioCDEncoder*> encoders;
 	cdrom_drive * getDrive();
 
 	// These are the only garenteed encoders to be built, the rest
